@@ -3,7 +3,7 @@ import functools
 import json
 from enum import Enum
 from json import JSONEncoder
-from typing import Dict, List, Optional, Union
+from typing import List, Optional
 from uuid import UUID
 
 from dateutil import parser
@@ -74,7 +74,7 @@ class PayerType(Enum):
 
 class PaymentDataSplit(BaseModel):
     code: str
-    amount: float
+    amount: Optional[float]
     meta: dict
 
     class Config:
@@ -94,12 +94,7 @@ class PaymentData(BaseModel):
     notice_code: Optional[str]
     iud: str
     iuv: Optional[str]
-    split: Union[
-        List[Dict[str, Union[float, str, None]]],
-        List[Optional[PaymentDataSplit]],
-        Dict[str, Optional[float]],
-        None,
-    ]
+    split: List[Optional[PaymentDataSplit]]
 
     class Config:
         validate_all = True
@@ -108,15 +103,6 @@ class PaymentData(BaseModel):
     paid_at_must_be_iso8601 = validator('paid_at', allow_reuse=True)(check_isoformat_none_case)
     expire_at_must_be_iso8601 = validator('expire_at', allow_reuse=True)(check_iso_format)
 
-    def set_split(self, split):
-        if isinstance(split, List):  # lo split è una lista di voci di bilancio
-            try:
-                self.split = [PaymentDataSplit(**item) for item in split]
-            except (ValidationError, TypeError):
-                self.split = split
-        elif isinstance(split, Dict) or not split:  # lo split cpntiene l'importo di ogni voce di bilancio o un None
-            self.split = split
-
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
 
@@ -255,8 +241,8 @@ class Payment(BaseModel):
 
     @validator('event_version')
     def event_version_must_be_two(cls, v):
-        if '1' not in v:
-            raise ValidationError('event must have 1.0 as version')
+        if float(v) != 2.0:
+            raise ValidationError('event must have 2.0 as version')
         return v.title()
 
     event_created_at_must_be_iso8601 = validator('event_created_at', allow_reuse=True)(check_iso_format)
