@@ -178,7 +178,7 @@ def get_payment_event_data(**kwargs):
             'email': 'raffaele.luccisano@opencontent.it',
         },
         'event_id': 'c5cebc1a-5d6f-4921-bc15-ff0575ea6f75',
-        'event_version': '1.0',
+        'event_version': '2.0',
         'event_created_at': '2022-06-08T08:28:42+00:00',
         'app_id': 'payment-dispatcher:1.0.15',
         **kwargs,
@@ -209,7 +209,7 @@ def get_split_data(**kwargs):
     }
 
 
-def get_split_data_v2(**kwargs):
+def get_split_data_invalid(**kwargs):
     return {
         'c_1': '14.00',
         'c_2': None,
@@ -217,25 +217,29 @@ def get_split_data_v2(**kwargs):
     }
 
 
-def get_split_data_v2_complete():
+def get_split_data_complete():
     return [
         {
-            'id': 'c_1',
-            'tipo': 'Tipo c1',
-            'codice': 'Codice c1',
-            'descrizione': 'Descrizione c1',
-            'importo': 16.0,
-            'capitolo_bilancio': 'Capitolo di bilancio c1',
-            'accertamento': 'Accertamento c1',
+            'code': 'c_1',
+            'amount': '16.00',
+            'meta': {
+                'split_type': 'Tipo c1',
+                'split_code': 'Codice c1',
+                'split_description': 'Descrizione c1',
+                'split_budget_chapter': 'Capitolo di bilancio c1',
+                'split_assessment': 'Accertamento c1',
+            },
         },
         {
-            'id': 'c_2',
-            'tipo': 'Tipo c2',
-            'codice': 'Codice c2',
-            'descrizione': 'Descrizione c12',
-            'importo': 0.5,
-            'capitolo_bilancio': 'Capitolo di bilancio c2',
-            'accertamento': 'Accertamento c2',
+            'code': 'c_2',
+            'amount': '0.50',
+            'meta': {
+                'split_type': 'Tipo c2',
+                'split_code': 'Codice c2',
+                'split_description': 'Descrizione c12',
+                'split_budget_chapter': 'Capitolo di bilancio c2',
+                'split_assessment': 'Accertamento c2',
+            },
         },
     ]
 
